@@ -1,6 +1,7 @@
 "githelp.py -- helpers for doing things on git"
 
-import git, fnmatch, os, collections
+import fnmatch
+import git
 
 def parse_rev_to_tuple(rev_string):
   if '...' in rev_string:
@@ -18,9 +19,8 @@ def get_paths(tree, pattern, root=()):
   found = []
   for item in tree:
     if isinstance(item, git.Blob):
-      path = os.path.join(*root, item.name)
-      if fnmatch.fnmatch(path, pattern):
-        found.append(path)
+      if fnmatch.fnmatch(item.abspath, pattern):
+        found.append(item.path)
     elif isinstance(item, git.Tree):
       found.extend(get_paths(item, pattern, root + (item.name,)))
     else:
